@@ -92,7 +92,7 @@ enum global_modus {
   gmodus_warte_gewonnen, // ... weil der Level fertig ist
   gmodus_bonus_animation, // Zeit-Bonus bekommen...
   gmodus_bonus_warte, 	  // Nach dem Zeit-Bonus noch ein bisschen warten
-  gmodus_ende_warte, // Kurz vor gmodus_kein_spiel: Benutzer darf noch
+  gmodus_ende_warte  // Kurz vor gmodus_kein_spiel: Benutzer darf noch
               // seine Punkte bewundern. Wenn er eine Taste drueckt, geht's
 	      // Zurueck ins Menue.
 } mGModus;
@@ -910,14 +910,8 @@ void init() {
   }
 
   /* Pause-Bild laden */
-  try {
-    mPauseBild = new Bilddatei();
-    mPauseBild->laden("pause.xpm");
-  } catch (Fehler f) {
-    fprintf(stderr, _("Could not load pause.xpm:\n"));
-    fprintf(stderr, "%s\n", f.getText().data());
-    mPauseBild = 0;
-  }
+  mPauseBild = new Bilddatei();
+  mPauseBild->laden("pause.xpm");
 
   /* KI-Spieler erzeugen */
   mKI = new KIPlayer(mSpielfeld[1]);
