@@ -125,7 +125,7 @@ int const_werte[const_anz] = {
 
 
 /* Fr den internen Gebrauch in Schleifen: Die pics-artigen keys. */
-char * gPicsetc[] = {
+const char * gPicsetc[] = {
   "pics",
   "greypic",
   "startpic",
@@ -228,7 +228,7 @@ void DefKnoten::fuegeEin(const Str & na, const Version & version,
 
     /* Achtung, verwirrend: wert ist nicht der Wert der Konstante,
        sondern das, was rechts vom "=" in der ld-Datei steht. */
-    for (char ** i=gPicsetc; *i; i++)
+    for (const char ** i=gPicsetc; *i; i++)
       if (na==*i)
 	speicherPicsConst(version, wert, *i);
     /* Wenn es den Namen schon gab, sind wir ganz still, denn das ist OK. */
@@ -322,7 +322,7 @@ void DefKnoten::speicherGlobaleVordefinierte() {
     Alternativ auch bei greypic und startpic.
     Welches davon steht in schluessel */
 void DefKnoten::speicherPicsConst(const Version& version, Knoten * picsliste,
-				  char* schluessel) {
+				  const char* schluessel) {
   /* Eigentlich knnten wir gleich eine Fehlermeldung
      ausspucken, wenn der Typ von picsliste falsch ist, aber die anderen
      entsprechenden Typ-Fehlermeldungen kommen auch erst beim Starten des
